==> haskell-hspec-2.7.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.7.0
id: hspec-2.7.0-AFxGaOzQIsX68sNMYD5TAn
key: hspec-2.7.0-AFxGaOzQIsX68sNMYD5TAn
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
abi: 39f6a6b76a998d47b1c518a5a6f332e7
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner
hidden-modules: Paths_hspec
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-2.7.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-2.7.0
hs-libraries: HShspec-2.7.0-AFxGaOzQIsX68sNMYD5TAn
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    hspec-core-2.7.0-A1mY8UkXgxdD2IiW3Iltvu
    hspec-discover-2.7.0-1HY7ubdFVlOJwxiCxcMmh6
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.7.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.7.0
id: hspec-2.7.0-A3pAMKtXpEw2A6n4SyMnIY
key: hspec-2.7.0-A3pAMKtXpEw2A6n4SyMnIY
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
abi: 59926e0fc5c3c5082212738b8ae30bc5
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner
hidden-modules: Paths_hspec
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-2.7.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-2.7.0
hs-libraries: HShspec-2.7.0-A3pAMKtXpEw2A6n4SyMnIY
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    hspec-core-2.7.0-JrARMmO11lFBE82excsNgV
    hspec-discover-2.7.0-1HY7ubdFVlOJwxiCxcMmh6
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
